summaryrefslogtreecommitdiffstatshomepage
path: root/src/emu/screen.h
diff options
context:
space:
mode:
author Aaron Giles <aaron@aarongiles.com>2012-01-02 07:37:22 +0000
committer Aaron Giles <aaron@aarongiles.com>2012-01-02 07:37:22 +0000
commit70a40085ebc14e1961486957bcefc80485c7ab20 (patch)
treeaa096722e26c7559bcc523da79becff2b77c054d /src/emu/screen.h
parent6130a83ecd7278097eb2d072a7142115d9b4e3fe (diff)
Removed machine.generic.tmpbitmap, VIDEO_START(generic_bitmapped),
and SCREEN_UPDATE(generic_bitmapped). In their place, each screen_device now maintains a default bitmap which is automatically copied to the screen on each update if no SCREEN_UPDATE function is provided and if no driver_device::video_update override is present. This bitmap can be found by querying the screen's new default_bitmap() method. [Aaron Giles]
Diffstat (limited to 'src/emu/screen.h')
-rw-r--r--src/emu/screen.h8
1 files changed, 5 insertions, 3 deletions
diff --git a/src/emu/screen.h b/src/emu/screen.h
index 48109eb0062..16beda4af97 100644
--- a/src/emu/screen.h
+++ b/src/emu/screen.h
@@ -150,6 +150,7 @@ public:
// additional helpers
void register_vblank_callback(vblank_state_delegate vblank_callback);
bitmap_t *alloc_compatible_bitmap(int width = 0, int height = 0) { return auto_bitmap_alloc(machine(), (width == 0) ? m_width : width, (height == 0) ? m_height : height, format()); }
+ bitmap_t &default_bitmap() { return m_default; }
// internal to the video system
bool update_quads();
@@ -208,14 +209,15 @@ private:
// textures and bitmaps
render_texture * m_texture[2]; // 2x textures for the screen bitmap
- bitmap_t * m_bitmap[2]; // 2x bitmaps for rendering
- bitmap_t * m_burnin; // burn-in bitmap
+ bitmap_t m_bitmap[2]; // 2x bitmaps for rendering
+ bitmap_t m_default; // default backing bitmap (copied by default)
+ bitmap_t m_burnin; // burn-in bitmap
UINT8 m_curbitmap; // current bitmap index
UINT8 m_curtexture; // current texture index
INT32 m_texture_format; // texture format of bitmap for this screen
bool m_changed; // has this bitmap changed?
INT32 m_last_partial_scan; // scanline of last partial update
- bitmap_t * m_screen_overlay_bitmap; // screen overlay bitmap
+ bitmap_t m_screen_overlay_bitmap; // screen overlay bitmap
// screen timing
attoseconds_t m_frame_period; // attoseconds per frame